@@ -41,6 +41,8 @@ time_t Bayonne::start_time = 0;
 
 Audio::Encoding Bayonne::peer_encoding = Audio::unknownEncoding;
 Audio::timeout_t Bayonne::peer_framing = 0;
+BayonneTranslator *Bayonne::init_translator = NULL;
+const char *Bayonne::init_voicelib = "none/prompts";
 
 Bayonne::statetab Bayonne::states[] = {
 	{"initial", &BayonneSession::stateInitial, ' '},
