@@ -62,6 +62,7 @@ class __EXPORT BayonneDriver;
 class __EXPORT BayonneSession;
 class __EXPORT BayonneSpan;
 class __EXPORT BayonneService;
+class __EXPORT BayonneTranslator;
 
 /**
  * Generic Bayonne master class to reference various useful data types
@@ -103,6 +104,8 @@ public:
 	static BayonneDriver *start_driver;
 	static Audio::Encoding peer_encoding;
 	static Audio::timeout_t peer_framing;
+	static BayonneTranslator *init_translator;
+	static const char *init_voicelib;
 
 	/**
 	 * Telephony endpoint interface identifiers.
@@ -783,6 +786,8 @@ protected:
 	const char *id;
 
 	static const char *getToken(BayonneSession *s, Line *l, unsigned *idx);
+	static unsigned addItem(BayonneSession *s, unsigned count, const char *text);
+	static const char *getLast(BayonneSession *s, unsigned count);
 
 public:
 	/**
@@ -809,7 +814,7 @@ public:
 	 * @param iso module name to load.
 	 * @return true if successful.
 	 */
-	static bool loadTranslator(const char *prefix, const char *name);
+	static BayonneTranslator *loadTranslator(const char *prefix, const char *name);
 
 	/**
 	 * Translate a simple set of digits to spoken speech.
@@ -839,7 +844,7 @@ public:
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned order(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned sayorder(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate a number to spoken speech.
@@ -851,6 +856,17 @@ public:
          */
 	virtual unsigned number(BayonneSession *s, unsigned count, const char *cp);
 
+	/**
+	 * Translate generic numbers to spoken speech.  This is the one
+	 * used by the &number rule.
+	 *
+	 * @param timeslot session to save list of prompts.
+	 * @param current count of prompts used.
+	 * @param string to be processed.
+	 * @return new count of prompts used.
+	 */
+	virtual unsigned saynumber(BayonneSession *s, unsigned count, const char *cp);
+
         /**
          * Translate a counting number (integer) to spoken speech.
          *
@@ -859,7 +875,7 @@ public:
          * @param string to be processed.
          * @return new count of prompts used.
          */
-	virtual unsigned counting(BayonneSession *s, unsigned count, const char *cp);
+	virtual unsigned saycount(BayonneSession *s, unsigned count, const char *cp);
 
         /**
          * Translate a string for time into speech.
@@ -928,6 +944,14 @@ public:
 	 * @param timeslot session to process a command from.
          */
 	virtual const char *speak(BayonneSession *session, Line *line = NULL);
+
+	/**
+	 * Get the id string.
+	 *
+	 * @return id string.
+	 */
+	inline const char *getId(void)
+		{return id;};
 };
 
 /**
@@ -1701,6 +1725,25 @@ protected:
 	 */
 	bool setLibexec(int result);
 
+public:
+	/**
+	 * Get the current language translator.
+	 *
+	 * @return translator.
+	 */
+	inline BayonneTranslator *getTranslator(void)
+		{return translator;};
+
+protected:
+	/**
+	 * Get the libaudio object.  Used by server libexec to prepare
+	 * a libaudio/phrasebook session.
+	 *
+	 * @return libaudio object for this session.
+	 */
+	inline libaudio_t *getLibaudio(void)
+		{return state.libaudio;};
+
 	/**
 	 * ccengine.
 	 */
