@@ -185,8 +185,6 @@ BayonneDriver *BayonneDriver::loadDriver(const char *prefix, const char *id)
 	if(d)
 		return d;
 
-	printf("path %s\n", path);
-
 	if(!canAccess(path))
 	{
 		server->errlog("access", path);
@@ -199,7 +197,6 @@ BayonneDriver *BayonneDriver::loadDriver(const char *prefix, const char *id)
 		server->errlog("error", dso->getError());
 		return NULL;
 	}
-	printf("ID %s\n", id);
 	return get(id);
 }
 	
