@@ -50,11 +50,14 @@ ScriptInterp(), audio()
 	starttime = 0;
 	type = NONE;
 	seizure = CHILD_RUNNING;
-	voicelib = "none/prompts";
-	translator = &langNone;
+	voicelib = init_voicelib;
+	translator = init_translator;
 	state.menu = NULL;
 	peer = NULL;
 
+	if(!translator)
+		translator = &langNone;
+
 	if(ts >= ts_used)
 		ts_used = ts + 1;
 
@@ -107,10 +110,6 @@ void BayonneSession::initialize(void)
 
 void BayonneSession::detach(void)
 {
-	var_sid[0] = 0;
-	
-	strcpy(var_rings, "0");
-
 	exittimer = 0;
 	answered = false;
 	digit_count = ring_count = 0;
@@ -118,12 +117,18 @@ void BayonneSession::detach(void)
 	disableDTMF();
 
 	ScriptInterp::detach();
+	var_sid[0] = 0;
+	strcpy(var_rings, "0");
 
 	starttime = 0;
 	type = NONE;
 	seizure = CHILD_RUNNING;
-	voicelib = "none/prompts";
-	translator = &langNone;
+	voicelib = init_voicelib;
+	translator = init_translator;
+
+	if(!translator)
+		translator = &langNone;
+
 	state.menu = NULL;
 	strcpy(audio.var_position, "00:00:00.000");
 }
