@@ -48,7 +48,9 @@ BayonneTranslator::BayonneTranslator(const char *name)
 BayonneTranslator *BayonneTranslator::get(const char *id)
 {
 	BayonneTranslator *bts = first;
+	char nid[3];
 
+retry:
 	while(bts)
 	{
 		if(!stricmp(bts->id, id))
@@ -56,6 +58,15 @@ BayonneTranslator *BayonneTranslator::get(const char *id)
 
 		bts = bts->next;
 	}
+	if(id[2] == '_')
+	{
+		nid[0] = id[0];
+		nid[1] = id[1];
+		nid[2] = 0;
+		id = nid;
+		bts = first;
+		goto retry;
+	}
 	return NULL;
 }
 
@@ -107,7 +118,7 @@ unsigned BayonneTranslator::saydate(BayonneSession *s, unsigned count, const cha
         --month;
 	s->state.audio.list[count++] = months[month];
 	snprintf(buf, sizeof(buf), "%d", day);
-	count = order(s, count, buf);
+	count = sayorder(s, count, buf);
 	
 	if(year < 2000 || year > 2009)
 	{
@@ -195,7 +206,7 @@ const char *cp) {
 	return count;	
 }
 
-unsigned BayonneTranslator::order(BayonneSession *s, unsigned count, const char *cp)
+unsigned BayonneTranslator::sayorder(BayonneSession *s, unsigned count, const char *cp)
 {
 	long num;
 
@@ -245,6 +256,11 @@ unsigned BayonneTranslator::order(BayonneSession *s, unsigned count, const char
 	return count;
 }
 
+unsigned BayonneTranslator::saynumber(BayonneSession *s, unsigned count, const char *cp)
+{
+	return number(s, count, cp);
+}
+
 unsigned BayonneTranslator::number(BayonneSession *s, unsigned count, const char *cp)
 {
 	long num;
@@ -278,7 +294,7 @@ unsigned BayonneTranslator::number(BayonneSession *s, unsigned count, const char
 	return count;
 }
 
-unsigned BayonneTranslator::counting(BayonneSession *s, unsigned count, const char *cp)
+unsigned BayonneTranslator::saycount(BayonneSession *s, unsigned count, const char *cp)
 {
 	long num;
 
@@ -413,6 +429,17 @@ unsigned BayonneTranslator::saytime(BayonneSession *s, unsigned count, const cha
 	return count;
 }
 
+unsigned BayonneTranslator::addItem(BayonneSession *s, unsigned count, const char *text)
+{
+	s->state.audio.list[count++] = text;
+	return count;
+}
+
+const char *BayonneTranslator::getLast(BayonneSession *s, unsigned count)
+{
+	return s->state.audio.list[--count];
+}
+
 const char *BayonneTranslator::getToken(BayonneSession *s, Line *line, unsigned *idx)
 {
 	const char *cp;
@@ -473,9 +500,9 @@ const char *BayonneTranslator::speak(BayonneSession *s, Line *l)
 		else if(!stricmp(cp, "&date"))
 			count = saydate(s, count, getToken(s, l, &idx));
 		else if(!stricmp(cp, "&order"))
-			count = order(s, count, getToken(s, l, &idx));
+			count = sayorder(s, count, getToken(s, l, &idx));
 		else if(!stricmp(cp, "&number"))
-			count = number(s, count, getToken(s, l, &idx));
+			count = saynumber(s, count, getToken(s, l, &idx));
 		else if(!stricmp(cp, "&phone"))
 			count = phone(s, count, getToken(s, l, &idx));
 		else if(!stricmp(cp, "&extension"))
@@ -483,7 +510,7 @@ const char *BayonneTranslator::speak(BayonneSession *s, Line *l)
 		else if(!stricmp(cp, "&bool"))
 			count = saybool(s, count, getToken(s, l, &idx));
 		else if(!stricmp(cp, "&count"))
-			count = counting(s, count, getToken(s, l, &idx));
+			count = saycount(s, count, getToken(s, l, &idx));
 		else if(!stricmp(cp, "&zero"))
 		{
 			cp = getToken(s, l, &idx);
@@ -520,3 +547,72 @@ const char *BayonneTranslator::speak(BayonneSession *s, Line *l)
 	return NULL;
 }
 				
+BayonneTranslator *BayonneTranslator::loadTranslator(const char *prefix, const char *id)
+{
+        DSO *dso;
+        BayonneTranslator *d;
+        char pathbuf[256];
+        const char *cp;
+        const char *path;
+	char nid[3];
+
+#ifdef  WIN32
+        if(!prefix)
+                prefix="C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Translators";
+#else
+        if(!prefix)
+                prefix=LIBDIR_FILES;
+#endif  
+
+retry:
+        cp = strrchr(id, '/');
+        if(!cp)
+                cp = strrchr(id, '\\');
+        if(!cp)
+                cp = strrchr(id, ':');
+
+        if(!cp)
+        {
+#ifdef  WIN32
+        	snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, id);
+#else
+                snprintf(pathbuf, sizeof(pathbuf),
+                	"%s/%s.phrases", prefix, id);
+#endif
+                path = pathbuf;
+        }  
+        else
+        {
+                path = id;
+                id = ++cp;
+        }
+ 
+        d = get(id);
+        if(d)
+                return d;  
+
+        if(!canAccess(path))
+        {
+		if(id[2] == '_')
+		{
+			nid[0] = id[0];
+			nid[1] = id[1];
+			nid[2] = 0;
+			id = nid;
+			goto retry;
+		}
+
+		if(server)
+	                server->errlog("access", path);
+                return NULL;
+        }
+
+        dso = new DSO(path);
+        if(!dso->isValid())
+        {
+		if(server)
+	                server->errlog("error", dso->getError());
+                return NULL;
+        }
+        return get(id);  
+}
