@@ -404,7 +404,7 @@ done:
 				if(dtmf && codec && n == size)
 				{
 					codec->decode(session->lbuffer, session->buffer, info.framecount);
-					dtmfdigits = dtmf->putSamples(session->lbuffer, info.framecount);					
+					dtmfdigits = dtmf->putSamples(session->lbuffer, info.framecount) > 0;					
 				}
                 	        if(sink)
                         	        sink->putBuffer(session->buffer, n);
@@ -426,7 +426,7 @@ done:
 				if(dtmf && codec && n == size)
 				{
 					codec->decode(session->lbuffer, session->buffer, info.framecount);
-					dtmfdigits = dtmf->putSamples(session->lbuffer, info.framecount);
+					dtmfdigits = dtmf->putSamples(session->lbuffer, info.framecount) > 0;
 				}
 				if(sink)
 					sink->putBuffer(session->buffer, n);
