@@ -22,6 +22,38 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+const char *Checks::chkCDR(Line *line, ScriptImage *img)
+{
+	char var[65];
+	char *p;
+	unsigned idx = 0;
+	const char *cp;
+
+	Name *scr = img->getCurrent();
+	snprintf(var, sizeof(var), "cdr.%s", scr->name);
+	p = strchr(var, ':');
+	if(p)
+		*p = 0;
+
+	if(img->getPointer(var))
+		return "cdr already assigned for this script file";
+
+	if(getMember(line))
+		return "cdr uses no members";
+
+	if(hasKeywords(line))
+		return "cdr has no keywords";
+
+	while(NULL != (cp = getOption(line, &idx)))
+	{
+		if(!isalpha(*cp) && *cp != '%')
+			return "invalid cdr entry used";
+	}
+
+	img->setPointer(var, line);
+	return "";
+}
+
 const char *Checks::chkDial(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
@@ -232,6 +264,23 @@ const char *Checks::chkDir(Line *line, ScriptImage *img)
 	return "";
 }
 
+const char *Checks::chkLang(Line *line, ScriptImage *img)
+{
+	unsigned idx = 0;
+	const char *cp;
+
+	if(getMember(line))
+		return "lang has no members";
+
+	if(hasKeywords(line))
+		return "lang has no keywords";
+
+	while(NULL != (cp = getOption(line, &idx)))
+		BayonneTranslator::loadTranslator(keypaths.getLast("phrases"), cp);
+		
+	return "";
+}
+
 const char *Checks::chkLoad(Line *line, ScriptImage *img)
 {
 	unsigned count = 0;
@@ -491,9 +540,6 @@ const char *Checks::chkPathname(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
 	
-	if(getMember(line))
-		return "command has no members";
-
 	if(!useKeywords(line, "=extension=voice=encoding=prefix"))
 		return "invalid keyword used";
 
