@@ -84,7 +84,7 @@ static Keydata::Define paths[] = {
 static Keydata::Define server[] = {
 	{"user", "bayonne"},
 	{"group", "bayonne"},
-	{"language", "en_us"},
+	{"language", "none"},
 	{"location", "us"},
 	{"voice", "none/prompts"},
 	{"state", "init"},
@@ -440,7 +440,7 @@ live:
 
 void parseConfig(char **argv)
 {
-	char buffer[65];
+	char buffer[64];
 	char path[256];
 	const char *prefix;
 	char *option;
