@@ -63,6 +63,10 @@ ScriptRuntime()
                         (Check)&Checks::chkTone},
                 {"callback", false, (Method)&Methods::scrTone,
                         (Check)&Checks::chkTone},
+		{"lang", true, (Method)&ScriptMethods::scrNop,
+			(Check)&Checks::chkLang},
+		{"languages", true, (Method)&ScriptMethods::scrNop,
+			(Check)&Checks::chkLang},
 		{"load", true, (Method)&ScriptMethods::scrNop,
 			(Check)&Checks::chkLoad},
 		{"dir", true, (Method)&ScriptMethods::scrNop,
@@ -81,6 +85,8 @@ ScriptRuntime()
 			(Check)&ScriptChecks::chkOnlyCommand},
                 {"hangup", false, (Method)&Methods::scrHangup, 
                         (Check)&ScriptChecks::chkOnlyCommand},
+		{"cdr", false, (Method)&ScriptMethods::scrNop,
+			(Check)&Checks::chkCDR},
 		{"select", false, (Method)&ScriptMethods::scrNop,
 			(Check)&Checks::chkSelect},
 		{"incoming", false, (Method)&ScriptMethods::scrNop,
@@ -182,6 +188,8 @@ ScriptRuntime()
 	ScriptInterp::addConditional("driver", &testDriver);
 	ScriptInterp::addConditional("timeslot", &testTimeslot);
 	ScriptInterp::addConditional("voice", &testVoice);
+	ScriptInterp::addConditional("lang", &testLang);
+	ScriptInterp::addConditional("language", &testLang);
 }
 
 unsigned long Runtime::getTrapMask(const char *trapname)
@@ -447,6 +455,23 @@ bool Runtime::testVoice(ScriptInterp *interp, const char *v)
 	return s->audio.isVoicelib(v);
 }
 
+bool Runtime::testLang(ScriptInterp *interp, const char *v)
+{
+	BayonneSession *s = (BayonneSession *)(interp);
+	BayonneTranslator *t = s->getTranslator();
+	const char *id = t->getId();
+
+	if(!id[2] || id[2] == '_')
+	{
+		if(!strnicmp(id, v, 2))
+			return true;
+	}
+	else if(!stricmp(id, v))
+		return true;
+
+	return false;
+}	
+
 #ifdef	WIN32
 
 void Runtime::process(void)
@@ -644,6 +669,17 @@ bool Runtime::command(char *cmd)
 		return false;
 	}			
 
+	if(!strnicmp(cmd, "lang", 4))
+	{
+		cmd = strtok_r(NULL, " \t\r\n", &tok);
+		while(cmd)
+		{
+			BayonneTranslator::loadTranslator(keypaths.getLast("phrases"), cmd);
+			cmd = strtok_r(NULL, " \t\r\n", &tok);
+		}
+		return true;
+	}
+		
 	if(!stricmp(cmd, "load"))
 	{
 		cmd = strtok_r(NULL, " \t\r\n", &tok);
