@@ -99,16 +99,47 @@ static void loadStack(const char *id)
 
 static void loading(void)
 {
+	char buffer[256];
+	char lang[32];
 	char ** keys;
 	const char *cp;
+	char *sp;
 	const char *dname = keyserver.getLast("driver");
 	unsigned count = keyoptions.getCount("modules");
 	BayonneDriver *driver;
+	BayonneTranslator *translator = NULL;
 
 #ifdef	HAVE_LIBEXEC
 	Libexec::allocate();
 #endif
 
+        cp = keyserver.getLast("language");
+        if(cp && (strlen(cp) == 2 || cp[2] == '_'))  
+		BayonneTranslator::loadTranslator(keypaths.getLast("phrases"), cp);  
+
+        cp = keyserver.getLast("voice");
+        if(cp && strchr(cp, '/'))
+        {
+                setString(lang, sizeof(lang), cp);
+                sp = strchr(lang, '/');
+                if(sp)
+                        *sp = 0;
+                if(strlen(lang) == 2 || sp[2] == '_')
+                        translator = BayonneTranslator::loadTranslator(keypaths.getLast("phrases"), lang);
+
+	}
+
+	if(cp && translator)
+	{
+		snprintf(buffer, sizeof(buffer), "%s/%s", keypaths.getLast("prompts"), cp);
+		if(isDir(buffer))
+		{
+			slog.debug("using %s as default voice library", cp);
+			Bayonne::init_translator = translator;
+			Bayonne::init_voicelib = cp;
+		}
+        } 
+
 	driver = BayonneDriver::loadDriver(keypaths.getLast("drivers"), dname);
 	if(!driver)
 		stop(-1);
