@@ -108,6 +108,18 @@ public:
 //	void adjust(char *data, size_t size, long offset);
 };
 
+class Binder : public ScriptBinder, public ScriptChecks
+{
+private:
+        void attach(ScriptInterp *interp);
+        void detach(ScriptInterp *interp);  
+
+public:
+	Binder();
+
+	static Binder binder;
+};
+
 class Runtime : public ScriptRuntime, public Bayonne
 {
 protected:
@@ -119,6 +131,7 @@ protected:
 	static bool testSpan(ScriptInterp *interp, const char *v);
 	static bool testDriver(ScriptInterp *interp, const char *v);
 	static bool testVoice(ScriptInterp *interp, const char *v);
+	static bool testLang(ScriptInterp *interp, const char *v);
 
 public:
 	static void process(void);
@@ -186,6 +199,7 @@ public:
 class Checks : public ScriptChecks, public Bayonne
 {
 public:
+	const char *chkCDR(Line *line, ScriptImage *img);
 	const char *chkTonegen(Line *line, ScriptImage *img);
 	const char *chkRegister(Line *line, ScriptImage *img);
 	const char *chkAssign(Line *line, ScriptImage *img);
@@ -206,6 +220,7 @@ public:
 	const char *chkAppend(Line *line, ScriptImage *img);
 	const char *chkVoicelib(Line *line, ScriptImage *img);
 	const char *chkLibexec(Line *line, ScriptImage *img);
+	const char *chkLang(Line *line, ScriptImage *img);
 	const char *chkLoad(Line *line, ScriptImage *img);
 	const char *chkBuild(Line *line, ScriptImage *img);
 	const char *chkTone(Line *line, ScriptImage *img);
